#[non_exhaustive]pub enum Cancelled {
#[non_exhaustive] PendingWrite,
#[non_exhaustive] PropagatedPanic,
}Expand description
A panic payload indicating that execution of a salsa query was cancelled.
This can occur for a few reasons: * * *
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]PendingWrite
The query was operating on revision R, but there is a pending write to move to revision R+1.
#[non_exhaustive]PropagatedPanic
The query was blocked on another thread, and that thread panicked.
Implementations