pub struct CancellationToken(/* private fields */);Expand description
A cancellation token that can be used to cancel a query computation for a specific local Database.
Implementations
Sourceimpl CancellationToken
impl CancellationToken
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if the query computation has been requested to be cancelled.