Cycle

Struct Cycle 

pub struct Cycle<'a> { /* private fields */ }
The context that the cycle recovery function receives when a query cycle occurs.

Implementations

Source

impl Cycle<'_>

pub fn head_ids(&self) -> CycleHeadIdsIterator<'_>

An iterator that outputs the Ids of the current cycle heads. This always contains the Id of the current query but it can contain additional cycle head Ids if this query is nested in an outer cycle or if it has nested cycles.

pub fn id(&self) -> Id

The Id of the query that the current cycle recovery function is processing.

pub fn iteration(&self) -> u32

The counter of the current fixed point iteration.