pub trait Accumulator:
Send
+ Sync
+ Any
+ Sized
+ UnwindSafe {
const DEBUG_NAME: &'static str;
// Required method
fn accumulate<Db>(self, db: &Db)
where Db: ?Sized + Database;
}Expand description
Trait implemented on the struct that user annotated with #[salsa::accumulator].
The Self type is therefore the types to be accumulated.
Required Associated Constants
const DEBUG_NAME: &'static str
Required Methods
Sourcefn accumulate<Db>(self, db: &Db)
fn accumulate<Db>(self, db: &Db)
Accumulate an instance of this in the database for later retrieval.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".